@@ -129,7 +129,7 @@ def file_and_permission_checks() -> Iterator[CheckError]:
         cf_type('/etc/machine.secret', 'root', 'root', 0o600, must_exist=True),
         cf_type('/etc/pam_ldap.secret', 'root', 'root', 0o600, must_exist=True),
         cf_type('/etc/idp-ldap-user.secret', 'root', 'DC Backup Hosts', 0o640, must_exist=is_primary),
-        cf_type('/etc/libnss-ldap.conf', 'messagebus', 'root', 0o440, must_exist=True),
+        cf_type('/etc/nslcd.conf', 'messagebus', 'root', 0o440, must_exist=True),
         cf_type('/var/run/slapd/ldapi', 'root', 'root', 0o700, False),
         cf_type('/etc/univention/ssl', 'root', 'DC Backup Hosts' if is_dc else 'root', 0o755, must_exist=True),
         cf_type('/etc/univention/ssl/openssl.cnf', 'root', 'DC Backup Hosts', 0o660, must_exist=is_primary),
@@ -178,8 +178,7 @@ def file_and_permission_checks() -> Iterator[CheckError]:
         check_file_args.append(cf_type(saml_key, 'root', 'samlcgi', 0o640, must_exist=True))
 
     for kwarg in check_file_args:
-        for error in check_file(*kwarg):
-            yield error
+        yield from check_file(*kwarg)
 
 
 def run(_umc_instance: Instance) -> None:
